<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Arhiv';
$labels['buttontitle'] = 'Arhiviraj to sporočilo';
$labels['archived'] = 'Sporočilo je bilo uspešno arhivirano';
$labels['archivedreload'] = 'Uspešno  shranjeno v arhiv. Za pregled map v Arhivu ponovno naložite stran.';
$labels['archiveerror'] = 'Nekaterih sporočil ni bilo mogoče arhivirati';
$labels['archivefolder'] = 'Arhiv';
$labels['settingstitle'] = 'Arhiv';
$labels['archivetype'] = 'Razdeli arhiv glede na';
$labels['archivetypeyear'] = 'Leto (npr. Arhiv/2012)';
$labels['archivetypemonth'] = 'Mesec (npr. Arhiv/2012/06)';
$labels['archivetypetbmonth'] = 'Mesec - podprto tudi v odjemalcu Thunderbird (npr. Arhiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Izvorna mapa';
$labels['archivetypesender'] = 'Naslov pošiljatelja';
$labels['unkownsender'] = 'neznan';
$labels['readonarchive'] = 'Ob arhiviranju označi sporočilo kot prebrano';
