<?php

// autoload.php @generated by Composer

require_once __DIR__ . '/composer/autoload_real.php';

return ComposerAutoloaderInit93a4011a767df69f92cb20ccea9547e3::getLoader();
// generated by Roundcube install 1.6.15
