<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'Goym í skjalasavni';
$labels['buttontitle'] = 'Goym hetta boð í skjalasavni';
$labels['archived'] = 'Goymt í skjalasavn';
$labels['archivedreload'] = 'Goymt í skjalasavn. Les inn aftur síðu fyri at síggja nýggjar mappur';
$labels['archiveerror'] = 'Onkur boð kundu ikki leggjast í skjalagoymslu';
$labels['archivefolder'] = 'Goym í skjalasavni';
$labels['settingstitle'] = 'Goym í skjalasavni';
$labels['archivetype'] = 'Deil skjalagoymslu við';
$labels['archivetypeyear'] = 'Ár (t.d. Skjalagoymsla/2012)';
$labels['archivetypemonth'] = 'Mánar(t.d. Skjalahgoymsla/2012/06)';
$labels['archivetypefolder'] = 'Uppruna mappa';
$labels['archivetypesender'] = 'Sendara teldupostur';
$labels['unkownsender'] = 'ókent';
