<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-archive/
*/

$labels['buttontext'] = 'أرشفة';
$labels['buttontitle'] = 'أرشفة هذه الرسالة';
$labels['archived'] = 'تم أرشفة الرسالة بنجاح';
$labels['archivefolder'] = 'أرشفة';
$labels['settingstitle'] = 'أرشفة';
$labels['archivetype'] = 'تقسيم الأرشيف بحسب';
$labels['archivetypefolder'] = 'المجلد الأصلي';
$labels['unkownsender'] = 'مجهول';
